==> libssh-docs-0.11.3-1-x86_64.pkg.tar.zst: usr/share/doc/libssh/html/group__libssh__channel.js <==
var group__libssh__channel =
[
    [ "channel_read_buffer", "group__libssh__channel.html#gab391f5c978cb1bc8df3ebd061f38e8c5", null ],
    [ "ssh_channel_accept_forward", "group__libssh__channel.html#ga490e4b0a7adc022507b7f165b336afe4", null ],
    [ "ssh_channel_accept_x11", "group__libssh__channel.html#ga548bd0f77a50b7c8180942544b375866", null ],
    [ "ssh_channel_cancel_forward", "group__libssh__channel.html#ga3bff751afc5ecb5bbf9d6447e4e5370f", null ],
    [ "ssh_channel_change_pty_size", "group__libssh__channel.html#gaf5d55c90f3d98c583df23d21905c1127", null ],
    [ "ssh_channel_close", "group__libssh__channel.html#ga238f07e0455456a5bfd8a49ead917732", null ],
    [ "ssh_channel_free", "group__libssh__channel.html#gad1417f9eae8928fed20faafe2d9dbfff", null ],
    [ "ssh_channel_get_exit_state", "group__libssh__channel.html#ga17b249b4abd204fc776a902bddc14c01", null ],
    [ "ssh_channel_get_exit_status", "group__libssh__channel.html#ga9eea019dd0bbaa8a817fff2c762d1a2d", null ],
    [ "ssh_channel_get_session", "group__libssh__channel.html#ga747aa5315575aa7ac9d8367c7372d8dd", null ],
    [ "ssh_channel_is_closed", "group__libssh__channel.html#gab2720b44cb7f1dfe2b38ffe07c2f45c7", null ],
    [ "ssh_channel_is_eof", "group__libssh__channel.html#gab535264029443d77214c0615a0788b0a", null ],
    [ "ssh_channel_is_open", "group__libssh__channel.html#gaaafcda943c96ddb91e5c28c0bdee7045", null ],
    [ "ssh_channel_listen_forward", "group__libssh__channel.html#ga758cda957227751870c8772df46e5b39", null ],
    [ "ssh_channel_new", "group__libssh__channel.html#gada8ccda7bf65165fe145d3096a252dcc", null ],
    [ "ssh_channel_open_auth_agent", "group__libssh__channel.html#ga6c4d4f5436dd5be58973606c6bcd8bb4", null ],
    [ "ssh_channel_open_forward", "group__libssh__channel.html#gae86b0704a1f2bdebb268b55567f7f47b", null ],
    [ "ssh_channel_open_forward_port", "group__libssh__channel.html#ga4dce3b5fb6755ec0f610846b220f50ff", null ],
    [ "ssh_channel_open_forward_unix", "group__libssh__channel.html#ga93ddd5055eb3322d38c70986aa63c673", null ],
    [ "ssh_channel_open_reverse_forward", "group__libssh__channel.html#ga9f66bf86a741ba17fe097dcb0594260e", null ],
    [ "ssh_channel_open_session", "group__libssh__channel.html#gaf051dd30d75bf6dc45d1a5088cf970bd", null ],
    [ "ssh_channel_open_x11", "group__libssh__channel.html#gae4aa2cb2a96cfe13712150517d6a90da", null ],
    [ "ssh_channel_poll", "group__libssh__channel.html#ga157f7d1df5de07ec6c6976e2034ba6e2", null ],
    [ "ssh_channel_poll_timeout", "group__libssh__channel.html#gab56c7b7959e4c23959f2989468811661", null ],
    [ "ssh_channel_read", "group__libssh__channel.html#gac92381c4c5d4a7eab35f6e84686f033d", null ],
    [ "ssh_channel_read_nonblocking", "group__libssh__channel.html#gaaca5a3fbe9839c3ffb37b746afc35f4c", null ],
    [ "ssh_channel_read_timeout", "group__libssh__channel.html#ga2f4e02cb3b3adbc30a534623164068fd", null ],
    [ "ssh_channel_request_auth_agent", "group__libssh__channel.html#gab2e28b520b8f8fe5ff5626de2a4113d9", null ],
    [ "ssh_channel_request_env", "group__libssh__channel.html#ga7aede2f9af4c494ff9e41fc08a4572f1", null ],
    [ "ssh_channel_request_exec", "group__libssh__channel.html#ga567d509183ade0a77190f390e2b5747d", null ],
    [ "ssh_channel_request_pty", "group__libssh__channel.html#ga37c1cec33fe5a2f184768aba52e3a0db", null ],
    [ "ssh_channel_request_pty_size_modes", "group__libssh__channel.html#ga2ebd34c7f15182e9fc1dde66863cf8d9", null ],
    [ "ssh_channel_request_send_break", "group__libssh__channel.html#gaef198ad0dcf0968aa2a449c8898d985e", null ],
    [ "ssh_channel_request_send_exit_signal", "group__libssh__channel.html#gabd3a5c8ef800f6c6ffdcc5f62557434c", null ],
    [ "ssh_channel_request_send_exit_status", "group__libssh__channel.html#gadc35e456e45b92c1e1da0fff8b6dfec9", null ],
    [ "ssh_channel_request_send_signal", "group__libssh__channel.html#gaa98315fca818b561970a6950683f4053", null ],
    [ "ssh_channel_request_sftp", "group__libssh__channel.html#ga3d2a402cddd799036006294eb61649fe", null ],
    [ "ssh_channel_request_shell", "group__libssh__channel.html#gaed4c5fb30c9df2b2548421ccf4e81bf1", null ],
    [ "ssh_channel_request_subsystem", "group__libssh__channel.html#ga06024b070f9b2a3d6964b79ae36695b7", null ],
    [ "ssh_channel_request_x11", "group__libssh__channel.html#gadfa34624c28164bd73453cd04aa64c1f", null ],
    [ "ssh_channel_select", "group__libssh__channel.html#ga1026cfa48ecfc0b4898d4ea443acfc5d", null ],
    [ "ssh_channel_send_eof", "group__libssh__channel.html#ga072f82fdf3e50514f747653af2c99004", null ],
    [ "ssh_channel_set_blocking", "group__libssh__channel.html#ga1c00ed18679d9a8c5b971260b5df13a2", null ],
    [ "ssh_channel_set_counter", "group__libssh__channel.html#gab0649fe21b7a900b4a8e10ecb3401395", null ],
    [ "ssh_channel_window_size", "group__libssh__channel.html#gadf53c5a5b501086af26d06cba3f1491f", null ],
    [ "ssh_channel_write", "group__libssh__channel.html#ga5d658df773ba854b35ff9f905341e2fb", null ],
    [ "ssh_channel_write_stderr", "group__libssh__channel.html#ga7ebd0ed490ee4485c6d5feb7d22bc162", null ]
];

==> libssh-docs-0.12.0-1-x86_64.pkg.tar.zst: usr/share/doc/libssh/html/group__libssh__channel.js <==
var group__libssh__channel =
[
    [ "channel_read_buffer", "group__libssh__channel.html#gab391f5c978cb1bc8df3ebd061f38e8c5", null ],
    [ "ssh_channel_accept_forward", "group__libssh__channel.html#ga490e4b0a7adc022507b7f165b336afe4", null ],
    [ "ssh_channel_accept_x11", "group__libssh__channel.html#ga548bd0f77a50b7c8180942544b375866", null ],
    [ "ssh_channel_cancel_forward", "group__libssh__channel.html#ga3bff751afc5ecb5bbf9d6447e4e5370f", null ],
    [ "ssh_channel_change_pty_size", "group__libssh__channel.html#gaf5d55c90f3d98c583df23d21905c1127", null ],
    [ "ssh_channel_close", "group__libssh__channel.html#ga238f07e0455456a5bfd8a49ead917732", null ],
    [ "ssh_channel_free", "group__libssh__channel.html#gad1417f9eae8928fed20faafe2d9dbfff", null ],
    [ "ssh_channel_get_exit_state", "group__libssh__channel.html#ga17b249b4abd204fc776a902bddc14c01", null ],
    [ "ssh_channel_get_exit_status", "group__libssh__channel.html#ga9eea019dd0bbaa8a817fff2c762d1a2d", null ],
    [ "ssh_channel_get_session", "group__libssh__channel.html#ga747aa5315575aa7ac9d8367c7372d8dd", null ],
    [ "ssh_channel_is_closed", "group__libssh__channel.html#gab2720b44cb7f1dfe2b38ffe07c2f45c7", null ],
    [ "ssh_channel_is_eof", "group__libssh__channel.html#gab535264029443d77214c0615a0788b0a", null ],
    [ "ssh_channel_is_open", "group__libssh__channel.html#gaaafcda943c96ddb91e5c28c0bdee7045", null ],
    [ "ssh_channel_listen_forward", "group__libssh__channel.html#ga758cda957227751870c8772df46e5b39", null ],
    [ "ssh_channel_new", "group__libssh__channel.html#gada8ccda7bf65165fe145d3096a252dcc", null ],
    [ "ssh_channel_open_auth_agent", "group__libssh__channel.html#ga6c4d4f5436dd5be58973606c6bcd8bb4", null ],
    [ "ssh_channel_open_forward", "group__libssh__channel.html#gae86b0704a1f2bdebb268b55567f7f47b", null ],
    [ "ssh_channel_open_forward_port", "group__libssh__channel.html#ga4dce3b5fb6755ec0f610846b220f50ff", null ],
    [ "ssh_channel_open_forward_unix", "group__libssh__channel.html#ga93ddd5055eb3322d38c70986aa63c673", null ],
    [ "ssh_channel_open_reverse_forward", "group__libssh__channel.html#ga9f66bf86a741ba17fe097dcb0594260e", null ],
    [ "ssh_channel_open_session", "group__libssh__channel.html#gaf051dd30d75bf6dc45d1a5088cf970bd", null ],
    [ "ssh_channel_open_x11", "group__libssh__channel.html#gae4aa2cb2a96cfe13712150517d6a90da", null ],
    [ "ssh_channel_poll", "group__libssh__channel.html#ga157f7d1df5de07ec6c6976e2034ba6e2", null ],
    [ "ssh_channel_poll_timeout", "group__libssh__channel.html#gab56c7b7959e4c23959f2989468811661", null ],
    [ "ssh_channel_read", "group__libssh__channel.html#gac92381c4c5d4a7eab35f6e84686f033d", null ],
    [ "ssh_channel_read_nonblocking", "group__libssh__channel.html#gaaca5a3fbe9839c3ffb37b746afc35f4c", null ],
    [ "ssh_channel_read_timeout", "group__libssh__channel.html#ga2f4e02cb3b3adbc30a534623164068fd", null ],
    [ "ssh_channel_request_auth_agent", "group__libssh__channel.html#gab2e28b520b8f8fe5ff5626de2a4113d9", null ],
    [ "ssh_channel_request_env", "group__libssh__channel.html#ga7aede2f9af4c494ff9e41fc08a4572f1", null ],
    [ "ssh_channel_request_exec", "group__libssh__channel.html#ga567d509183ade0a77190f390e2b5747d", null ],
    [ "ssh_channel_request_pty", "group__libssh__channel.html#ga37c1cec33fe5a2f184768aba52e3a0db", null ],
    [ "ssh_channel_request_pty_size", "group__libssh__channel.html#gabb175414352256e1602286e0ab50886c", null ],
    [ "ssh_channel_request_pty_size_modes", "group__libssh__channel.html#ga2ebd34c7f15182e9fc1dde66863cf8d9", null ],
    [ "ssh_channel_request_send_break", "group__libssh__channel.html#gaef198ad0dcf0968aa2a449c8898d985e", null ],
    [ "ssh_channel_request_send_exit_signal", "group__libssh__channel.html#gabd3a5c8ef800f6c6ffdcc5f62557434c", null ],
    [ "ssh_channel_request_send_exit_status", "group__libssh__channel.html#gadc35e456e45b92c1e1da0fff8b6dfec9", null ],
    [ "ssh_channel_request_send_signal", "group__libssh__channel.html#gaa98315fca818b561970a6950683f4053", null ],
    [ "ssh_channel_request_sftp", "group__libssh__channel.html#ga3d2a402cddd799036006294eb61649fe", null ],
    [ "ssh_channel_request_shell", "group__libssh__channel.html#gaed4c5fb30c9df2b2548421ccf4e81bf1", null ],
    [ "ssh_channel_request_subsystem", "group__libssh__channel.html#ga06024b070f9b2a3d6964b79ae36695b7", null ],
    [ "ssh_channel_request_x11", "group__libssh__channel.html#gadfa34624c28164bd73453cd04aa64c1f", null ],
    [ "ssh_channel_select", "group__libssh__channel.html#ga1026cfa48ecfc0b4898d4ea443acfc5d", null ],
    [ "ssh_channel_send_eof", "group__libssh__channel.html#ga072f82fdf3e50514f747653af2c99004", null ],
    [ "ssh_channel_set_blocking", "group__libssh__channel.html#ga1c00ed18679d9a8c5b971260b5df13a2", null ],
    [ "ssh_channel_set_counter", "group__libssh__channel.html#gab0649fe21b7a900b4a8e10ecb3401395", null ],
    [ "ssh_channel_window_size", "group__libssh__channel.html#gadf53c5a5b501086af26d06cba3f1491f", null ],
    [ "ssh_channel_write", "group__libssh__channel.html#ga5d658df773ba854b35ff9f905341e2fb", null ],
    [ "ssh_channel_write_stderr", "group__libssh__channel.html#ga7ebd0ed490ee4485c6d5feb7d22bc162", null ]
];
